@@ -357,39 +357,48 @@ class GradeCSVProcessor(DeferrableMixin, GradedSubsectionMixin, CSVProcessor):
         Preprocess the CSV row.
         """
         operation = {}
-        if row['user_id'] in self._users_seen:
-            return operation
+        user_id = row['user_id']
+        if user_id in self._users_seen:
+            raise ValidationError(_('Repeated user_id: ') + str(user_id))
+
+        operation['new_override_grades'] = []
+        operation['course_id'] = self.course_id
+        operation['user_id'] = user_id
+
         for key in row:
             if key.startswith('new_override-'):
                 value = row[key].strip()
                 if value:
                     short_id = key.split('-', 1)[1]
                     subsection = self._subsections[short_id][0]
-                    operation['user_id'] = row['user_id']
-                    operation['course_id'] = self.course_id
-                    operation['block_id'] = str(subsection.location)
+                    block_id = str(subsection.location)
                     try:
-                        operation['new_override'] = float(value)
+                        new_grade = float(value)
                     except ValueError as error:
                         raise ValidationError(_('Grade must be a number')) from error
-                    if operation['new_override'] < 0:
-                        raise ValidationError(_('Grade must be positive'))
-        self._users_seen.add(row['user_id'])
+                    else:
+                        if new_grade < 0:
+                            raise ValidationError(_('Grade must not be negative'))
+                        operation['new_override_grades'].append((block_id, new_grade))
+
+        self._users_seen.add(user_id)
         return operation
 
     def process_row(self, row):
         """
         Save a row to the persistent subsection override table.
         """
-        grades_api.override_subsection_grade(
-            row['user_id'],
-            row['course_id'],
-            row['block_id'],
-            overrider=self._user,
-            earned_graded=row['new_override'],
-            feature='grade-import',
-            comment='Bulk Grade Import',
-        )
+        for block_id, new_grade in row['new_override_grades']:
+            grades_api.override_subsection_grade(
+                row['user_id'],
+                row['course_id'],
+                block_id,
+                overrider=self._user,
+                earned_graded=new_grade,
+                feature='grade-import',
+                comment='Bulk Grade Import',
+            )
+
         return True, None
 
     def get_rows_to_export(self):
@@ -473,7 +482,8 @@ class GradeCSVProcessor(DeferrableMixin, GradedSubsectionMixin, CSVProcessor):
 
             # Get changes this row introduced for an as-yet-unmodified subsection
             for subsection in unmodified_subsections:
-                if row[f'new_override-{subsection}'].strip() != '':
+                override_column = f'new_override-{subsection}'
+                if override_column in row and row[override_column].strip() != '':
                     subsections_modified_by_row.add(subsection)
 
             # Remove modified subsections from the unmodified list
