@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 URLs for bulk_grades.
 """
@@ -10,17 +9,17 @@ from . import views
 
 urlpatterns = [
     url(
-        r'^bulk_grades/course/{}/$'.format(settings.COURSE_ID_PATTERN),
+        fr'^bulk_grades/course/{settings.COURSE_ID_PATTERN}/$',
         views.GradeImportExport.as_view(),
         name='bulk_grades'
     ),
     url(
-        r'^bulk_grades/course/{}/history/$'.format(settings.COURSE_ID_PATTERN),
+        fr'^bulk_grades/course/{settings.COURSE_ID_PATTERN}/history/$',
         views.GradeOperationHistoryView.as_view(),
         name='bulk_grades.history'
     ),
     url(
-        r'^bulk_grades/course/{}/intervention/$'.format(settings.COURSE_ID_PATTERN),
+        fr'^bulk_grades/course/{settings.COURSE_ID_PATTERN}/intervention/$',
         views.InterventionsExport.as_view(),
         name='interventions'
     ),
