@@ -44,7 +44,6 @@ class GradeOnlyExport(View):
         self.initialize_processor(request, course_id)
         return super().dispatch(request, course_id, *args, **kwargs)
 
-    # pylint: disable=unused-argument
     def get(self, request, course_id, *args, **kwargs):
         """
         Export grades in CSV format.
@@ -73,7 +72,6 @@ class GradeImportExport(GradeOnlyExport):
     CSV Grade import/export view.
     """
 
-    # pylint: disable=unused-argument
     def post(self, request, course_id, *args, **kwargs):
         """
         Import grades from a CSV file.
@@ -91,6 +89,16 @@ class GradeImportExport(GradeOnlyExport):
             the_file = request.FILES['csv']
             self.processor.process_file(the_file, autocommit=True)
             data = self.processor.status()
+            data['error_messages'] = []
+            for error_message in self.processor.error_messages:
+                line_numbers = ', '.join(str(line_number+1) for line_number in self.processor.error_messages[error_message])
+                new_message = '{error_message} on line{is_plural} {line_numbers}'.format(
+                                    error_message=error_message,
+                                    is_plural='s' if len(line_numbers) > 1 else '',
+                                    line_numbers=line_numbers
+                                )
+                data['error_messages'].append(new_message)
+
             log.info('Processed file %s for %s -> %s saved, %s processed, %s error. (async=%s)',
                      the_file.name,
                      course_id,
